[Asterisk-code-review] spelling: amount (asterisk[master])

Josh Soref asteriskteam at digium.com
Sun Nov 7 00:03:30 CDT 2021


Josh Soref has uploaded this change for review. ( https://gerrit.asterisk.org/c/asterisk/+/16721 )


Change subject: spelling: amount
......................................................................

spelling: amount

Change-Id: I35d8abc81bb2891a883883cc4bdc9a15b95138c6
---
M addons/ooh323c/src/ooSocket.h
M contrib/utils/eagi_proxy.c
2 files changed, 5 insertions(+), 5 deletions(-)



  git pull ssh://gerrit.asterisk.org:29418/asterisk refs/changes/21/16721/1

diff --git a/addons/ooh323c/src/ooSocket.h b/addons/ooh323c/src/ooSocket.h
index b4cbf88..48ddd62 100644
--- a/addons/ooh323c/src/ooSocket.h
+++ b/addons/ooh323c/src/ooSocket.h
@@ -328,7 +328,7 @@
  *                     whether write would block on them.
  * @param exceptfds    The descriptors listed in exceptfds will be watched for
  *                     exceptions.
- * @param timeout      Upper bound on amout of time elapsed before select
+ * @param timeout      Upper bound on amount of time elapsed before select
  *                     returns.
  * @return             Completion status of operation: 0 (ASN_OK) = success,
  *                     negative return value is error.
diff --git a/contrib/utils/eagi_proxy.c b/contrib/utils/eagi_proxy.c
index 117d51e..e87b932 100644
--- a/contrib/utils/eagi_proxy.c
+++ b/contrib/utils/eagi_proxy.c
@@ -83,11 +83,11 @@
 
 int connect_to_host(char* host, int port); /* connect to a given host (name or IP) and given port number in nonblocking mode returning socket descriptor*/
 
-void read_full(int file, char* buffer, int num); /* read EXACTLY "num" ammount of bytes from "file" descriptor to "buffer"*/
-int read_some(int file, char* buffer, int size); /* read AT MOST "size" ammount of bytes */
+void read_full(int file, char* buffer, int num); /* read EXACTLY "num" amount of bytes from "file" descriptor to "buffer"*/
+int read_some(int file, char* buffer, int size); /* read AT MOST "size" amount of bytes */
 
-void write_buf(int file, char* buffer, int num); /* write "num" ammount of bytes to "file" descriptor and buffer the surplus if the write would block */
-int write_amap(int file, char* buffer, int num); /*write AT MOST "num" ammount of bytes and return ammount that was written*/
+void write_buf(int file, char* buffer, int num); /* write "num" amount of bytes to "file" descriptor and buffer the surplus if the write would block */
+int write_amap(int file, char* buffer, int num); /*write AT MOST "num" amount of bytes and return amount that was written*/
 
 void setnonblocking(int desc); /*sets the socket non-blocking; for polling */
 

-- 
To view, visit https://gerrit.asterisk.org/c/asterisk/+/16721
To unsubscribe, or for help writing mail filters, visit https://gerrit.asterisk.org/settings

Gerrit-Project: asterisk
Gerrit-Branch: master
Gerrit-Change-Id: I35d8abc81bb2891a883883cc4bdc9a15b95138c6
Gerrit-Change-Number: 16721
Gerrit-PatchSet: 1
Gerrit-Owner: Josh Soref <jsoref at gmail.com>
Gerrit-CC: Friendly Automation
Gerrit-MessageType: newchange
-------------- next part --------------
An HTML attachment was scrubbed...
URL: <http://lists.digium.com/pipermail/asterisk-code-review/attachments/20211107/ef55c778/attachment-0001.html>


More information about the asterisk-code-review mailing list